@@ -28,7 +28,7 @@ use Encode 'encode';
 
 use Carp 'confess';
 
-our $VERSION = '0.0271';
+our $VERSION = '0.0272';
 
 our $COMPILER;
 our @PACKAGE_INFOS;
@@ -64,7 +64,7 @@ sub import {
 
 sub _get_dll_file {
   my $package_name = shift;
-  
+
   # DLL file name
   my $dll_base_name = $package_name;
   $dll_base_name =~ s/^.*:://;
@@ -96,6 +96,7 @@ sub search_native_address {
     if ($dll_libref) {
       my $sub_abs_name_c = $sub_abs_name;
       $sub_abs_name_c =~ s/:/_/g;
+      
       $native_address = DynaLoader::dl_find_symbol($dll_libref, $sub_abs_name_c);
     }
     else {
@@ -121,6 +122,7 @@ sub get_sub_native_address {
   
   my $dll_package_name = $package_name;
   my $shared_lib_file = _get_dll_file($dll_package_name);
+
   my $native_address = search_native_address($shared_lib_file, $sub_abs_name);
   
   # Try runtime compile
@@ -137,11 +139,19 @@ sub get_sub_native_address {
     $module_dir =~ s/$module_name_slash$//;
     $module_dir =~ s/\/$//;
     
-    my $shared_lib_file = SPVM::Build::build_shared_lib(
-      module_dir => $module_dir,
-      module_name => "SPVM::$module_name"
-    );
-    if ($shared_lib_file) {
+    my $shared_lib_file;
+    
+    eval {
+      $shared_lib_file = SPVM::Build::build_shared_lib(
+        module_dir => $module_dir,
+        module_name => "SPVM::$module_name"
+      );
+    };
+    
+    if ($@) {
+      return;
+    }
+    else {
       $native_address = search_native_address($shared_lib_file, $sub_abs_name);
     }
   }
@@ -155,7 +165,9 @@ sub bind_native_subs {
     my $native_func_name_spvm = "SPVM::$native_func_name";
     my $native_address = get_sub_native_address($native_func_name_spvm);
     unless ($native_address) {
-      confess "Can't find native address($native_func_name())";
+      my $native_func_name_c = $native_func_name_spvm;
+      $native_func_name_c =~ s/:/_/g;
+      confess "Can't find native address of $native_func_name_spvm(). Native function name must be $native_func_name_c";
     }
     bind_native_sub($native_func_name, $native_address);
   }
@@ -167,7 +179,16 @@ CHECK {
   XSLoader::load('SPVM', $VERSION);
   
   # Load standard library
-  my @dll_file_bases = ('std', 'Math');
+  my @dll_file_bases = qw(
+    std
+    Math
+    Byte
+    Short
+    Integer
+    Long
+    Float
+    Double
+  );
   for my $shared_lib_file_base (@dll_file_bases) {
     my $shared_lib_file_rel = "auto/SPVM/$shared_lib_file_base.native/$shared_lib_file_base.$Config{dlext}";
     for my $module_dir (@INC) {
