@@ -4,6 +4,10 @@
 #include <stdint.h>
 #include <stdlib.h>
 
+// spvm_sub_check_info.h
+struct SPVM_sub_check_info;
+typedef struct SPVM_sub_check_info SPVM_SUB_CHECK_INFO;
+
 // spvm_constant_pool_sub.h
 struct SPVM_constant_pool_sub;
 typedef struct SPVM_constant_pool_sub SPVM_CONSTANT_POOL_SUB;
