@@ -24,17 +24,8 @@ struct SPVM_runtime {
   // Constant pool subroutine symbol table
   SPVM_HASH* sub_id_symtable;
   
-  // Constant pool subroutine symbol table
-  SPVM_DYNAMIC_ARRAY* inline_file_ids;
-  
-  // Constant pool subroutine symbol table
-  SPVM_DYNAMIC_ARRAY* inline_package_name_ids;
-  
   SPVM_HASH* native_sub_name_ids_symtable;
   
-  // Inline file id symtable
-  SPVM_HASH* inline_file_id_symtable;
-  
   // Constant pool type symbol table
   SPVM_HASH* type_id_symtable;
   
